# Example: for use as a Resque job
# test in console to simulate resque job:
# turn off sql printing in rails console so we can see "puts" clearly:
# ActiveRecord::Base.logger = ::Logger.new(nil)
# bundle exec rails c
#   ew = EsWither.new
#   ew.wither_old_indices

class EsWither
  require 'elasticshelf'

  # this allows us to pass in different methods to perform from the Resque config/schedule.yml:
  class << self
    def perform(method)
      self.new.send(method)
    end
  end

  def initialize
    puts "#{Time.now.utc} EsWither::initialize:"
    @es = Elasticshelf::Client.new(:host => "#{APP_CONFIG[:elasticsearch_host]}:#{APP_CONFIG[:elasticsearch_port]}")
    @es.repo = "#{APP_CONFIG[:elasticsearch_host]}}_logs"
    @es.indices_prefix = "#{APP_CONFIG[:elasticsearch_host]}_logs-"
    puts "\trepo=#{@es.repo}"
    puts "\tindices_prefix=#{@es.indices_prefix}"
  end

  def wither_old_indices
    puts "#{Time.now.utc} EsWither::wither_old_indices: starting . . ."
    start_time = Time.now.utc
    @es.cutoff_days = 3
    puts "\tcutoff date=#{@es.cutoff_days_as_date_to_s}"
    # ************************
    @es.wither_expired_indices
    # ************************
    puts "\tindices_withered: #{@es.indices_withered.inspect}"
    puts "expired_indices:"
    @es.expired_indices.each { |k,v| puts "\t#{k}=#{v}" }
    puts "indices_rejected:"
    @es.indices_rejected.each
    puts "indices_affected:"
    @es.indices_affected.each { |k,v| puts "\t#{k}=#{v}" }
    puts "indices: #{@es.indices.inspect}"
    # verify bloom filter was disabled:
    @es.indices_withered.each do |k,v|
      @es.get_settings_index(k)
      puts "\tverifying index '#{k}' is withered"
      puts "\terrors=#{@es.errors.inspect}"
      puts "\tresults=#{@es.results.inspect}"
    end
    puts "#{Time.now.utc} EsWither::wither_old_indices: finished in #{Time.now.utc - start_time} secs"
  end
end
